@@ -9,9 +9,11 @@ select_engine.register(passes.AnnotateRepLinks)
 #select_engine.register(passes.DebugVisualizer)
 select_engine.register(passes.PrePeepHole)
 select_engine.register(passes.CreateExpressions)
-select_engine.register(passes.WrapperPlanner,debug_mode=True)
-#select_engine.register(passes.DebugVisualizer)
+select_engine.register(passes.WrapperPlanner,debug_mode=False)
 select_engine.register(passes.PythonPeepHole)
+#select_engine.register(passes.DebugVisualizer)
+select_engine.register(passes.Transposer)
+#select_engine.register(passes.DebugVisualizer)
 select_engine.register(passes.SerializeExec)
 select_engine.register(python.PyExec,debug_mode=False)
 #select_engine.register(passes.DebugVisualizer)
