@@ -1,4 +1,4 @@
 from dimensions import Dim
-from rtypes import createType
+from rtypes import createType, matchType
 from casts import findImplicitCastTypes, canCast, castImplicitCommonType
 from detector import Detector
