@@ -383,7 +383,7 @@ class NestedArray(object):
                 nself.idxs[matchpoint] = nlidx
         del nself.idxs[matchpoint+1]
         if(not isinstance(nself.idxs[matchpoint],int) and result_fixed):
-            nself._var_to_fixed(matchpoint)
+            nself._var_to_fixed(matchpoint), 
         return nself
 
     def _var_to_fixed(self, pos):
@@ -392,7 +392,8 @@ class NestedArray(object):
         diff = idx[...,-1] - idx[...,0]
         diffset = set(diff.ravel())
 
-        assert len(diffset) == 1, "Multiple lengths encountered while expecting fixed dim"
+        assert len(diffset)==1, "Multiple lengths encountered while expecting fixed dim"
+        
         nshape = diffset.pop()
         nextobj = nextobj.reshape(diff.shape + (nshape,) + nextobj.shape[1:])
 
@@ -444,7 +445,12 @@ class NestedArray(object):
                 tmp = pidx[lidx]
                 pidx[lidx] = pidx[ridx]
                 pidx[ridx] = tmp
-                nextobj = numpy.transpose(nextobj,axes=pidx)
+                #added copy to ensure that array is c-contiguous,
+                #as not being contiguous kills performance
+                #In the future, maybe we should move contigious checks
+                #to the operations that benefit from them, then we 
+                #can remove this copy (and the copy below in var-var)
+                nextobj = numpy.transpose(nextobj,axes=pidx).copy()
             else: #fixed-var --> var-fixed
                 fixshape = ridx.shape[-2]
                 nnextobj = numpy.zeros(nextobj.shape,dtype=nextobj.dtype)
@@ -537,7 +543,7 @@ class NestedArray(object):
                         rightlen= (rsrc.stop - rsrc.start) / leftlen
 
                     d = numpy.reshape(nextobj[rsrc],(leftlen,rightlen) +  nextobj.shape[1:])
-                    d = numpy.transpose(d,pidx)
+                    d = numpy.transpose(d,pidx).copy()
                     nnextobj[rsrc] = d.ravel()
                 nextobj = nnextobj
 
@@ -745,6 +751,7 @@ def co_mapseq(func, nested_arrays, *args, **kwargs):
     idxlen = set([len(na.idxs) for na in nested_arrays])
     assert len(idxlen) == 1, "Nested arrays should have same dimensions!"
     idxlen = idxlen.pop()
+
     na_ref = nested_arrays[0]
 
     #determine if there is incomplete broadcasting going on
@@ -753,10 +760,21 @@ def co_mapseq(func, nested_arrays, *args, **kwargs):
     xshape = []
     for i in range(idxlen):
         pos = idxlen -i - 1
-        if(not isinstance(na_ref.idxs[pos], int)):
+
+        nested = [not isinstance(na.idxs[pos],int) for na in nested_arrays]
+        if all(nested):
             break
-        
-        res = set([na.getDimShape(pos-1) for na in nested_arrays])
+        dshapes = [na.getDimShape(pos-1) for na in nested_arrays]
+        if any(nested):
+            for dpos in xrange(len(dshapes)):
+               if not isinstance(dshapes[dpos],int):
+                  red = set(dshapes[dpos])
+                  assert len(red) == 1, "Unequal dims (mixed nested/non-nested) in co_mapseq"
+                  nested_arrays[dpos]._var_to_fixed(pos)
+                  dshapes[dpos] = nested_arrays[dpos].getDimShape(pos-1)
+                  assert isinstance(dshapes[dpos],int), "After conversion to fixed dim still nested dim"
+          
+        res = set(dshapes)
         if len(res) > 1:
             assert len(res) == 2 and 1 in res, "Unequal dims in co_mapseq"
             lastpos = pos - 1
